@@ -6,15 +6,17 @@ __all__ = ["settings"]
 
 
 class CustomSettings:
-    INSIGHTS_APP_NAME: str = "MyApp"
-    INSIGHTS_MENU: dict[str, str] = {}
-    INSIGHTS_CHART_DPI: int = 180
+    """
+    Django Insight settings
 
+    """
+
+    INSIGHTS_APP_NAME: str = "MyApp"
+    INSIGHTS_CHART_DPI: int = 180
+    INSIGHTS_DEFAULT_THEME = "dark"
     INSIGHTS_CHART_LIGHT_PRIMARY_COLOR = "#2563EB"
     INSIGHTS_CHART_DARK_PRIMARY_COLOR = "#BFDBFE"
 
-    INSIGHTS_DEFAULT_THEME = "dark"
-
     def __getattribute__(self, name):
         try:
             return getattr(django_settings, name)
